import { QueueDriverInterface, QueueDriverConnectionInterface, QueryStageStateResponse, QueryDef, RetrieveForProcessingResponse, QueueDriverOptions, AddToQueueQuery, AddToQueueOptions, AddToQueueResponse, QueryKey, QueryKeyHash } from '@cubejs-backend/base-driver';
import { CubeStoreDriver } from './CubeStoreDriver';
declare class CubestoreQueueDriverConnection implements QueueDriverConnectionInterface {
    protected readonly driver: CubeStoreDriver;
    protected readonly options: QueueDriverOptions;
    constructor(driver: CubeStoreDriver, options: QueueDriverOptions);
    redisHash(queryKey: QueryKey): QueryKeyHash;
    protected prefixKey(queryKey: QueryKey): string;
    addToQueue(keyScore: number, queryKey: QueryKey, orphanedTime: any, queryHandler: string, query: AddToQueueQuery, priority: number, options: AddToQueueOptions): Promise<AddToQueueResponse>;
    getQueryAndRemove(hash: QueryKeyHash): Promise<[QueryDef]>;
    cancelQuery(hash: QueryKeyHash): Promise<QueryDef | null>;
    freeProcessingLock(_hash: QueryKeyHash, _processingId: string, _activated: unknown): Promise<void>;
    getActiveQueries(): Promise<string[]>;
    getToProcessQueries(): Promise<string[]>;
    getActiveAndToProcess(): Promise<[active: string[], toProcess: string[]]>;
    getNextProcessingId(): Promise<number | string>;
    getQueryStageState(onlyKeys: boolean): Promise<QueryStageStateResponse>;
    getResult(queryKey: QueryKey): Promise<unknown>;
    getStalledQueries(): Promise<string[]>;
    getOrphanedQueries(): Promise<string[]>;
    getQueriesToCancel(): Promise<string[]>;
    protected decodeQueryDefFromRow(row: {
        payload: string;
        extra?: string | null;
    }, method: string): QueryDef;
    getQueryDef(queryKey: QueryKeyHash): Promise<QueryDef | null>;
    optimisticQueryUpdate(queryKey: any, toUpdate: any, _processingId: any): Promise<boolean>;
    release(): void;
    retrieveForProcessing(queryKeyHashed: QueryKeyHash, _processingId: string): Promise<RetrieveForProcessingResponse>;
    getResultBlocking(queryKey: string): Promise<QueryDef | null>;
    getResultBlockingByHash(queryKeyHash: QueryKeyHash): Promise<QueryDef | null>;
    setResultAndRemoveQuery(hash: QueryKeyHash, executionResult: any, _processingId: any): Promise<boolean>;
    updateHeartBeat(hash: QueryKeyHash): Promise<void>;
}
export declare class CubeStoreQueueDriver implements QueueDriverInterface {
    protected readonly driverFactory: () => Promise<CubeStoreDriver>;
    protected readonly options: QueueDriverOptions;
    constructor(driverFactory: () => Promise<CubeStoreDriver>, options: QueueDriverOptions);
    protected connection: CubeStoreDriver | null;
    redisHash(queryKey: QueryKey): QueryKeyHash;
    protected getConnection(): Promise<CubeStoreDriver>;
    createConnection(): Promise<CubestoreQueueDriverConnection>;
    release(): void;
}
export {};
//# sourceMappingURL=CubeStoreQueueDriver.d.ts.map